#!/bin/sh

DIRNAME=`dirname "$0"`

. "$DIRNAME/definitions.sh"
. "$DIRNAME/functions.sh.in"

if [ $# -lt 1 ]; then
    echo "Usage: `basename "$0"` config" >&2
    exit 1;
fi

missing=
exec < "$1"
while IFS=, read action dest src flags; do
    if echo "$action" | grep -q "^#" ||
       [ -z "$action" -a -z "$dest" -a -z "$src" -a -z "$flags" ]; then
        continue;
    fi

    from="$DIRNAME/files/$src"

    if [ ! -e "$from" ]; then
        missing=1
        echo "Missing file referenced by config: $src" >&2
    fi

    if is_flag_set "$flags" force; then
        :
    elif [ x"$action" = xscript ]; then
        :
    elif is_flag_set "$flags" purge; then
        :
    elif [ ! -e "${from}.md5sum" ]; then
        missing=1
        echo -n "Missing history for file referenced by config: " >&2
        echo "${src}.md5sum" >&2
    fi
done

if [ -n "$missing" ]; then
    exit 1
fi
